@@ -1,8 +1,6 @@
-use std::convert::TryFrom;
-use std::slice::Iter;
+use std::{convert::TryFrom, slice::Iter};
 
-use crate::fragment::Fragment;
-use crate::trailer::Trailer;
+use crate::{fragment::Fragment, trailer::Trailer};
 
 /// A Collection of `Trailer`
 #[derive(Debug, PartialEq, Clone)]
@@ -17,8 +15,7 @@ impl Trailers {
     /// # Examples
     ///
     /// ```
-    /// use mit_commit::Trailer;
-    /// use mit_commit::Trailers;
+    /// use mit_commit::{Trailer, Trailers};
     /// let trailers = Trailers::from(vec![
     ///     Trailer::new("Co-authored-by", "Billie Thompson <billie@example.com>"),
     ///     Trailer::new("Co-authored-by", "Someone Else <someone@example.com>"),
@@ -53,8 +50,7 @@ impl Trailers {
     /// # Examples
     ///
     /// ```
-    /// use mit_commit::Trailer;
-    /// use mit_commit::Trailers;
+    /// use mit_commit::{Trailer, Trailers};
     /// let trailers = Trailers::from(vec![
     ///     Trailer::new("Co-authored-by", "Billie Thompson <billie@example.com>"),
     ///     Trailer::new("Co-authored-by", "Someone Else <someone@example.com>"),
@@ -72,8 +68,7 @@ impl Trailers {
     /// # Examples
     ///
     /// ```
-    /// use mit_commit::Trailer;
-    /// use mit_commit::Trailers;
+    /// use mit_commit::{Trailer, Trailers};
     /// assert_eq!(
     ///     Trailers::from(vec![
     ///         Trailer::new("Co-authored-by", "Billie Thompson <billie@example.com>"),
@@ -92,6 +87,45 @@ impl Trailers {
     }
 }
 
+impl IntoIterator for Trailers {
+    type IntoIter = std::vec::IntoIter<Trailer>;
+    type Item = Trailer;
+
+    /// Iterate over the trailers
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use mit_commit::{Trailer, Trailers};
+    /// let trailers = Trailers::from(vec![
+    ///     Trailer::new("Co-authored-by", "Billie Thompson <billie@example.com>"),
+    ///     Trailer::new("Co-authored-by", "Someone Else <someone@example.com>"),
+    ///     Trailer::new("Relates-to", "#124"),
+    /// ]);
+    /// let mut iterator = trailers.into_iter();
+    ///
+    /// assert_eq!(
+    ///     iterator.next(),
+    ///     Some(Trailer::new(
+    ///         "Co-authored-by",
+    ///         "Billie Thompson <billie@example.com>"
+    ///     ))
+    /// );
+    /// assert_eq!(
+    ///     iterator.next(),
+    ///     Some(Trailer::new(
+    ///         "Co-authored-by",
+    ///         "Someone Else <someone@example.com>"
+    ///     ))
+    /// );
+    /// assert_eq!(iterator.next(), Some(Trailer::new("Relates-to", "#124")));
+    /// assert_eq!(iterator.next(), None);
+    /// ```
+    fn into_iter(self) -> Self::IntoIter {
+        self.trailers.into_iter()
+    }
+}
+
 impl From<Vec<Trailer>> for Trailers {
     fn from(trailers: Vec<Trailer>) -> Self {
         Trailers {
@@ -142,15 +176,10 @@ impl From<Vec<Fragment>> for Trailers {
 
 #[cfg(test)]
 mod tests {
-    use pretty_assertions::assert_eq;
-
     use indoc::indoc;
 
-    use crate::fragment::Fragment;
-    use crate::trailer::Trailer;
-    use crate::Body;
-
     use super::Trailers;
+    use crate::{fragment::Fragment, trailer::Trailer, Body};
 
     #[test]
     fn implements_iterator() {
@@ -204,17 +233,14 @@ mod tests {
 
     #[test]
     fn it_can_tell_me_if_it_is_empty() {
-        assert_eq!(
-            Trailers::from(vec![
-                Trailer::new("Co-authored-by", "Billie Thompson <billie@example.com>"),
-                Trailer::new("Co-authored-by", "Someone Else <someone@example.com>"),
-            ])
-            .is_empty(),
-            false
-        );
+        assert!(!Trailers::from(vec![
+            Trailer::new("Co-authored-by", "Billie Thompson <billie@example.com>"),
+            Trailer::new("Co-authored-by", "Someone Else <someone@example.com>"),
+        ])
+        .is_empty());
 
         let trailers: Vec<Trailer> = Vec::new();
-        assert_eq!(Trailers::from(trailers).is_empty(), true);
+        assert!(Trailers::from(trailers).is_empty());
     }
 
     #[test]
